@@ -1,22 +1,16 @@
 #!/bin/bash
-#=======================================================================
 # 🦁 BRAVE BROWSER INSTALLATION SCRIPT 🦁
-#=======================================================================
 # This script installs the Brave browser on Linux systems
 # Reference: https://brave.com/linux/
 
-echo """#=======================================================================
-🚀 STARTING BRAVE BROWSER INSTALLATION | Installing dependencies
-#=======================================================================
+echo """🚀 STARTING BRAVE BROWSER INSTALLATION | Installing dependencies
 """
 
 # Install curl if not already installed
 echo "📥 Installing curl..."
 sudo nala install curl -y
 
-echo """#=======================================================================
-🔑 ADDING REPOSITORY KEYS | Setting up Brave repository
-#=======================================================================
+echo """🔑 ADDING REPOSITORY KEYS | Setting up Brave repository
 """
 
 # Add the Brave browser PGP key
@@ -27,9 +21,7 @@ sudo curl -fsSLo /usr/share/keyrings/brave-browser-archive-keyring.gpg https://b
 echo "📝 Adding Brave repository to sources list..."
 echo "deb [signed-by=/usr/share/keyrings/brave-browser-archive-keyring.gpg] https://brave-browser-apt-release.s3.brave.com/ stable main" | sudo tee /etc/apt/sources.list.d/brave-browser-release.list
 
-echo """#=======================================================================
-📦 INSTALLING BRAVE BROWSER | Updating and installing packages
-#=======================================================================
+echo """📦 INSTALLING BRAVE BROWSER | Updating and installing packages
 """
 
 # Update package lists
@@ -40,9 +32,7 @@ sudo nala update
 echo "📥 Installing Brave browser..."
 sudo nala install brave-browser -y
 
-echo """#=======================================================================
-✅ INSTALLATION COMPLETE | Brave browser has been installed successfully
-#=======================================================================
+echo """✅ INSTALLATION COMPLETE | Brave browser has been installed successfully
 """
 echo "🦁 You can now launch Brave browser from your applications menu or by typing 'brave-browser' in terminal"
 
