@@ -5,13 +5,13 @@
 from pathlib import Path
 from typing import cast, Optional, get_args, Annotated
 import typer
-from machineconfig.scripts.python.helpers_fire.fire_agents_helper_types import AGENTS, HOST, MODEL, PROVIDER
+from machineconfig.scripts.python.helpers_agents.fire_agents_helper_types import AGENTS, HOST, PROVIDER
 
 
 def create(
     agent: Annotated[AGENTS, typer.Option(..., "--agents", "-a", help=f"Agent type. One of {', '.join(get_args(AGENTS)[:3])}")],
     host: Annotated[HOST, typer.Option(..., "--host", "-h", help=f"Machine to run agents on. One of {', '.join(get_args(HOST))}")],
-    model: Annotated[MODEL, typer.Option(..., "--model", "-m", help=f"Model to use (for crush agent). One of {', '.join(get_args(MODEL)[:3])}")],
+    model: Annotated[str, typer.Option(..., "--model", "-m", help="Model to use (for crush agent).")],
     provider: Annotated[PROVIDER, typer.Option(..., "--provider", "-p", help=f"Provider to use (for crush agent). One of {', '.join(get_args(PROVIDER)[:3])}")],
     context_path: Annotated[Optional[Path], typer.Option(..., "--context-path", "-c", help="Path to the context file/folder, defaults to .ai/todo/")] = None,
     separator: Annotated[str, typer.Option(..., "--separator", "-s", help="Separator for context")] = "\n",
@@ -24,8 +24,8 @@ def create(
     agents_dir: Annotated[Optional[Path], typer.Option(..., "--agents-dir", "-ad", help="Directory to store agent files. If not provided, will be constructed automatically.")] = None,
 ):
 
-    from machineconfig.scripts.python.helpers_fire.fire_agents_help_launch import prep_agent_launch, get_agents_launch_layout
-    from machineconfig.scripts.python.helpers_fire.fire_agents_load_balancer import chunk_prompts
+    from machineconfig.scripts.python.helpers_agents.fire_agents_help_launch import prep_agent_launch, get_agents_launch_layout
+    from machineconfig.scripts.python.helpers_agents.fire_agents_load_balancer import chunk_prompts
     from machineconfig.utils.accessories import get_repo_root, randstr
     import json
 
@@ -85,7 +85,7 @@ agents create "{context_path_resolved}" \\
     --separator "{separator}" \\
     {"--separate" if separate else ""}
 """
-    (agents_dir / "aa_agents_relaunch.py").write_text(data=regenerate_py_code, encoding="utf-8")
+    (agents_dir / "aa_agents_relaunch.sh").write_text(data=regenerate_py_code, encoding="utf-8")
     layout_output_path = output_path if output_path is not None else agents_dir / "layout.json"
     layout_output_path.parent.mkdir(parents=True, exist_ok=True)
     layout_output_path.write_text(data=json.dumps(layoutfile, indent=4), encoding="utf-8")
@@ -136,11 +136,11 @@ def collect(
 
 def template():
     from platform import system
-    import machineconfig.scripts.python.helpers_fire as module
+    import machineconfig.scripts.python.helpers_agents as module
     if system() == "Linux" or system() == "Darwin":
-        template_path = Path(module.__file__).parent / "template.sh"
+        template_path = Path(module.__file__).parent / "templates/template.sh"
     elif system() == "Windows":
-        template_path = Path(module.__file__).parent / "template.ps1"
+        template_path = Path(module.__file__).parent / "templates/template.ps1"
     else:
         raise typer.BadParameter(f"Unsupported OS: {system()}")
 
@@ -168,8 +168,6 @@ def get_app():
 PROVIDER options: {', '.join(get_args(PROVIDER))}
 {sep}
 AGENT options: {', '.join(get_args(AGENTS))}
-{sep}
-MODEL options: {sep.join(get_args(MODEL))}
 """
     agents_app.command("create", no_args_is_help=True, help=agents_full_help)(create)
     agents_app.command("c", no_args_is_help=True, help="Create agents layout file, ready to run.", hidden=True)(create)
