@@ -3,33 +3,26 @@
 from typing import Literal, Annotated, Optional
 from pathlib import Path
 import typer
-
+import machineconfig.scripts.python.helpers_devops.cli_config_dotfile as dotfile_module
 
 
 def private(method: Annotated[Literal["symlink", "copy"], typer.Option(..., "--method", "-m", help="Method to use for linking files")],
-                             on_conflict: Annotated[Literal["throw-error", "overwriteSelfManaged", "backupSelfManaged", "overwriteDefaultPath", "backupDefaultPath"], typer.Option(..., "--on-conflict", "-o", help="Action to take on conflict")] = "throw-error",
+                             on_conflict: Annotated[Literal["throw-error", "overwrite-self-managed", "backup-self-managed", "overwrite-default-path", "backup-default-path"], typer.Option(..., "--on-conflict", "-o", help="Action to take on conflict")] = "throw-error",
                              which: Annotated[Optional[str], typer.Option(..., "--which", "-w", help="Specific items to process")] = None,
                              interactive: Annotated[bool, typer.Option(..., "--interactive", "-ia", help="Run in interactive mode")] = False):
     """🔗 Manage private configuration files."""
     import machineconfig.profile.create_links_export as create_links_export
     create_links_export.main_private_from_parser(method=method, on_conflict=on_conflict, which=which, interactive=interactive)
 
+
 def public(method: Annotated[Literal["symlink", "copy"], typer.Option(..., "--method", "-m", help="Method to use for setting up the config file.")],
-                            on_conflict: Annotated[Literal["throw-error", "overwriteDefaultPath", "backupDefaultPath"], typer.Option(..., "--on-conflict", "-o", help="Action to take on conflict")] = "throw-error",
+                            on_conflict: Annotated[Literal["throw-error", "overwrite-default-path", "backup-default-path"], typer.Option(..., "--on-conflict", "-o", help="Action to take on conflict")] = "throw-error",
                             which: Annotated[Optional[str], typer.Option(..., "--which", "-w", help="Specific items to process")] = None,
                             interactive: Annotated[bool, typer.Option(..., "--interactive", "-ia", help="Run in interactive mode")] = False):
     """🔗 Manage public configuration files."""
     import machineconfig.profile.create_links_export as create_links_export
     create_links_export.main_public_from_parser(method=method, on_conflict=on_conflict, which=which, interactive=interactive)
 
-def dotfile(file: Annotated[str, typer.Argument(help="file/folder path.")],
-    overwrite: Annotated[bool, typer.Option("--overwrite", "-o", help="Overwrite.")] = False,
-    dest: Annotated[str, typer.Option("--dest", "-d", help="destination folder")] = "",
-    ):
-    """🔗 Manage dotfiles."""
-    import machineconfig.scripts.python.helpers_devops.cli_config_dotfile as dotfile_module
-    dotfile_module.main(file=file, overwrite=overwrite, dest=dest)
-
 
 def shell():
     """🔗 Configure your shell profile."""
@@ -46,7 +39,7 @@ def path():
     uv_with = ["textual"]
     uv_project_dir = None
     if not Path.home().joinpath("code/machineconfig").exists():
-        uv_with.append("machineconfig>=6.96")
+        uv_with.append("machineconfig>=7.36")
     else:
         uv_project_dir = str(Path.home().joinpath("code/machineconfig"))
     run_shell_script(get_uv_command_executing_python_script(python_script=path.read_text(encoding="utf-8"), uv_with=uv_with, uv_project_dir=uv_project_dir)[0])
@@ -59,6 +52,7 @@ def pwsh_theme():
     import subprocess
     subprocess.run(["pwsh", "-File", str(file)])
 
+
 def starship_theme():
     """🔗 Select starship prompt theme."""
     import subprocess
@@ -87,6 +81,7 @@ def starship_theme():
     except ValueError:
         typer.echo("❌ Please enter a valid number")
 
+
 def copy_assets(which: Annotated[Literal["scripts", "settings", "both"], typer.Argument(..., help="Which assets to copy")]):
     """🔗 Copy asset files from library to machine."""
     import machineconfig.profile.create_helper as create_helper
@@ -104,8 +99,8 @@ def get_app():
     config_apps.command("v", no_args_is_help=True, hidden=True)(private)
     config_apps.command("public", no_args_is_help=True, help="🔗  [b] Manage public configuration files.")(public)
     config_apps.command("b", no_args_is_help=True, help="Manage public configuration files.", hidden=True)(public)
-    config_apps.command("dotfile", no_args_is_help=True, help="🔗  [d] Manage dotfiles.")(dotfile)
-    config_apps.command("d", no_args_is_help=True,  hidden=True)(dotfile)
+    config_apps.command("dotfile", no_args_is_help=True, help="🔗  [d] Manage dotfiles.")(dotfile_module.main)
+    config_apps.command("d", no_args_is_help=True,  hidden=True)(dotfile_module.main)
     config_apps.command("shell", no_args_is_help=False, help="🔗  [s] Configure your shell profile.")(shell)
     config_apps.command("s", no_args_is_help=False, help="Configure your shell profile.", hidden=True)(shell)
     config_apps.command("path", no_args_is_help=False, help="📚  [p] NAVIGATE PATH variable with TUI")(path)
