@@ -198,7 +198,7 @@ def init_project(python: Annotated[Literal["3.13", "3.14"], typer.Option("--pyth
     if not (repo_root / "pyproject.toml").exists():
         typer.echo("❌ Error: pyproject.toml not found.", err=True)
         raise typer.Exit(code=1)
-    print(f"Adding group `plot` with common data science and plotting packages...")
+    print("Adding group `plot` with common data science and plotting packages...")
     script = """
 uv add --group plot \
     # Data & computation
@@ -219,3 +219,20 @@ uv add --group plot \
 """
     from machineconfig.utils.code import run_shell_script
     run_shell_script(script)
+# def add_dev_packages(repo_dir: Annotated[Optional[str], typer.Option(..., "--repo-dir", "-r", help="Path to the repository root directory")] = None):
+#     if repo_dir is None:
+#         r_dir = Path.cwd()
+#     else:
+#         r_dir = Path(repo_dir).resolve()
+#     if not r_dir.exists() or not r_dir.is_dir() or not (r_dir / "pyproject.toml").exists():
+#         typer.echo(f"❌ The provided repo directory `{r_dir}` is not valid or does not contain a `pyproject.toml` file.")
+#         raise typer.Exit(code=1)
+#     command = f"""
+# cd "{r_dir}" || exit 1
+# uv add nbformat ipdb ipykernel ipython pylint pyright mypy pyrefly ty pytest
+# """
+#     from machineconfig.utils.code import run_shell_script
+#     typer.echo(f"➡️  Installing dev packages in repo at `{r_dir}`...")
+#     run_shell_script(command)
+#     typer.echo(f"✅ Dev packages installed successfully in repo at `{r_dir}`.")
+#     # TODO: see upgrade packages.
