@@ -51,7 +51,7 @@ def select_layout(layouts_json_file: Path, selected_layouts_names: Optional[list
 
 def find_layout_file(layout_path: str, ) -> Path:
     from machineconfig.utils.path_extended import PathExtended
-    from machineconfig.scripts.python.helpers_fire.helpers4 import search_for_files_of_interest
+    from machineconfig.scripts.python.helpers_fire_command.file_wrangler import search_for_files_of_interest
     from machineconfig.utils.options import choose_from_options
     from machineconfig.utils.path_helper import match_file_name, sanitize_path
     path_obj = sanitize_path(layout_path)
