@@ -37,7 +37,7 @@ add_to_path_if_not_already \
 . $CONFIG_ROOT/settings/broot/br.sh
 . $CONFIG_ROOT/settings/lf/linux/exe/lfcd.sh
 . $CONFIG_ROOT/settings/tere/terecd.sh
-. $CONFIG_ROOT/scripts/linux/mcfgs
+. $CONFIG_ROOT/scripts/linux/wrap_mcfg
 
 # check if file in ~/dotfiles/machineconfig/init_linux.sh exists and source it
 if [ -f "$HOME/dotfiles/machineconfig/init_linux.sh" ]; then
@@ -46,15 +46,16 @@ if [ -f "$HOME/dotfiles/machineconfig/init_linux.sh" ]; then
 fi
 
 alias l='lsd -la'
-alias d='wrap_in_op_program devops'
-alias c='wrap_in_op_program cloud'
-alias a='wrap_in_op_program agents'
-alias s='wrap_in_op_program sessions'
-alias ff='wrap_in_op_program ftpx'
-alias f='wrap_in_op_program fire'
-alias r='wrap_in_op_program croshell'
-alias u='wrap_in_op_program utils'
-alias t='wrap_in_op_program term'
+alias d='wrap_in_shell_script devops'
+alias c='wrap_in_shell_script cloud'
+alias a='wrap_in_shell_script agents'
+alias s='wrap_in_shell_script sessions'
+alias ff='wrap_in_shell_script ftpx'
+alias f='wrap_in_shell_script fire'
+alias r='wrap_in_shell_script croshell'
+alias u='wrap_in_shell_script utils'
+alias t='wrap_in_shell_script terminal'
+alias ms='wrap_in_shell_script msearch'
 
 
 # alias gcs='gh copilot suggest -t shell'
