@@ -125,7 +125,7 @@ def dynamically_extract_installers_system_groups_from_scripts():
     if system() == "Windows":
         from machineconfig.setup_windows import APPS
         options_system = parse_apps_installer_windows(APPS.read_text(encoding="utf-8"))
-    elif system() == "Linux" or system() == "Darwin":
+    elif system() == "Linux":
         from machineconfig.setup_linux import APPS
         options_system = parse_apps_installer_linux(APPS.read_text(encoding="utf-8"))
     elif system() == "Darwin":
@@ -146,7 +146,6 @@ def install_bulk(installers_data: list[InstallerData], safe: bool = False, jobs:
         print("🧹 Fresh install requested - clearing version cache...")
         PathExtended(INSTALL_VERSION_ROOT).delete(sure=True)
         print("✅ Version cache cleared")
-
     if safe:
         pass
         # print("⚠️  Safe installation mode activated...")
@@ -214,7 +213,6 @@ def get_machineconfig_version() -> str:
     from importlib.metadata import PackageNotFoundError, version as _pkg_version
     from pathlib import Path
     import tomllib
-
     name: str = "machineconfig"
     try:
         return _pkg_version(name)
