@@ -8,7 +8,7 @@ from machineconfig.utils.terminal import Response
 from machineconfig.utils.accessories import pprint, randstr
 from machineconfig.utils.meta import lambda_to_python_script
 UV_RUN_CMD = "$HOME/.local/bin/uv run" if platform.system() != "Windows" else """& "$env:USERPROFILE/.local/bin/uv" run"""
-MACHINECONFIG_VERSION = "machineconfig>=6.96"
+MACHINECONFIG_VERSION = "machineconfig>=7.36"
 DEFAULT_PICKLE_SUBDIR = "tmp_results/tmp_scripts/ssh"
 
 class SSH:
@@ -245,12 +245,15 @@ class SSH:
             from pathlib import Path
             import shutil
             directory_path = Path(target_rel2home).expanduser()
+            if not directory_path.is_absolute():
+                directory_path = Path.home().joinpath(directory_path)
             if overwrite and directory_path.exists():
                 if directory_path.is_dir():
                     shutil.rmtree(directory_path)
                 else:
                     directory_path.unlink()
             directory_path.parent.mkdir(parents=True, exist_ok=True)
+            directory_path.mkdir(parents=True, exist_ok=True)
         command = lambda_to_python_script(lmb=lambda: create_target_dir(target_rel2home=path_rel2home, overwrite=overwrite_existing), in_global=True, import_module=False)
         tmp_py_file = Path.home().joinpath(f"{DEFAULT_PICKLE_SUBDIR}/create_target_dir_{randstr()}.py")
         tmp_py_file.parent.mkdir(parents=True, exist_ok=True)
@@ -318,9 +321,11 @@ class SSH:
             tmp_py_file = Path.home().joinpath(f"{DEFAULT_PICKLE_SUBDIR}/create_target_dir_{randstr()}.py")
             tmp_py_file.parent.mkdir(parents=True, exist_ok=True)
             tmp_py_file.write_text(command, encoding="utf-8")
-            transferred_py_file = self.copy_from_here(source_path=str(tmp_py_file), target_rel2home=None, compress_with_zip=True, recursive=False, overwrite_existing=True)
-            self.run_shell(command=f"""{UV_RUN_CMD} python {transferred_py_file}""", verbose_output=False, description=f"UNZIPPING {target_rel2home}", strict_stderr=True, strict_return_code=True)
+            remote_tmp_py = tmp_py_file.relative_to(Path.home()).as_posix()
+            self.copy_from_here(source_path=str(tmp_py_file), target_rel2home=None, compress_with_zip=False, recursive=False, overwrite_existing=True)
+            self.run_shell(command=f"""{UV_RUN_CMD} python {remote_tmp_py}""", verbose_output=False, description=f"UNZIPPING {target_rel2home}", strict_stderr=True, strict_return_code=True)
             source_obj.unlink()
+            tmp_py_file.unlink(missing_ok=True)
         return None
 
     def _check_remote_is_dir(self, source_path: Union[str, Path]) -> bool:
@@ -388,7 +393,7 @@ class SSH:
         assert isinstance(result, str), f"Could not resolve source path {source_path}"
         return result
 
-    def copy_to_here(self, source: Union[str, Path], target: Optional[Union[str, Path]], compress_with_zip: bool = False, recursive: bool = False, internal_call: bool = False) -> Path:
+    def copy_to_here(self, source: Union[str, Path], target: Optional[Union[str, Path]], compress_with_zip: bool = False, recursive: bool = False, internal_call: bool = False) -> None:
         if self.sftp is None:
             raise RuntimeError(f"SFTP connection not available for {self.hostname}. Cannot transfer files.")
         
@@ -484,7 +489,7 @@ class SSH:
                     local_file_target = target_dir.joinpath(Path(file_path).relative_to(expanded_source))
                     self.copy_to_here(source=file_path, target=local_file_target, compress_with_zip=False, recursive=False, internal_call=True)
                 
-                return target_dir
+                return None
         
         if compress_with_zip:
             print("🗜️ ZIPPING ...")
@@ -607,7 +612,7 @@ class SSH:
             self.run_py(python_code=command, uv_with=[MACHINECONFIG_VERSION], uv_project_dir=None,  description="Cleaning temp zip files @ remote.", verbose_output=False, strict_stderr=True, strict_return_code=True)
         
         print("\n")
-        return target_obj
+        return None
 
 if __name__ == "__main__":
     ssh = SSH(host="p51s", username=None, hostname=None, ssh_key_path=None, password=None, port=22, enable_compression=False)
